@@ -283,7 +283,7 @@ class HgClient(VcsClientBase):
         return tags
 
     def get_latest_tag_name(self):
-        cmd_log = [HgClient._executable, 'log', '--rev', '.', '--template', '{latesttagdistance}']
+        cmd_log = [self._executable, 'log', '--rev', '.', '--template', '{latesttagdistance}']
         result_log = self._run_command(cmd_log)
         if result_log['returncode']:
             raise RuntimeError('Could not fetch latest tag:\n%s' % result_log['output'])
